#
# spec file for package civetweb
#
# Copyright (c) 2019 SUSE LLC
# Copyright (c) 2020 Mark Verlinde
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.


%define         soname  1_13_0
%define         _libname libcivetweb

Name:           civetweb
Summary:        A C/C++ web server
License:        MIT
Group:          Productivity/Networking/Web/Servers
Version:        1.13
Release:        1.1
URL:            https://github.com/civetweb/civetweb
Source0:        https://github.com/civetweb/civetweb/archive/v%{version}.tar.gz
Source1:        civetweb.conf
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  openssl-devel


%description
civetweb is a C/C++ embeddable web server with optional CGI, SSL and Lua support. 

%package -n %{_libname}%{soname}
Summary:        Shared Object for applications that use %{name} embedded
Group:          Productivity/Networking/Web/Servers

%description -n %{_libname}%{soname}
This package contains the shared library required by applications that
are using %{name}'s embeddable API to provide web services. 

%package devel
Summary:        Header files and development libraries for %{name}
Group:          Productivity/Networking/Web/Servers
Requires:       %{_libname}%{soname} = %{version}-%{release}

%description devel
This package contains the header files and development libraries
for %{name}. If you like to develop programs embedding %{name} on them,
you will need to install %{name}-devel and check %{name}'s API at its
comprisable header file.

%prep
%setup -q

install -pm0644  %{SOURCE1} .



%build
# Build outoff source-tree
mkdir builddir

pushd builddir
%cmake ../ -DCMAKE_BUILD_TYPE=None \
           -DCIVETWEB_BUILD_TESTING=OFF \
           -DCIVETWEB_ENABLE_CXX=OFF \
           -DBUILD_SHARED_LIBS=ON

%{make_build}
popd

%install
pushd builddir
%{make_install}
popd
#remove cmake files
rm -rf %{buildroot}%{_libdir}/cmake/%{name}/*cmake

%post -n %{_libname}%{soname} -p /sbin/ldconfig
%postun -n %{_libname}%{soname} -p /sbin/ldconfig

%files
%doc %{name}.conf
%license LICENSE.md
%{_bindir}/%{name}

%files -n %{_libname}%{soname}
%{_libdir}/lib%{name}.so.*

%files devel
%{_includedir}/%{name}.h
%{_libdir}/lib%{name}.so

%changelog
* Mon Jan 25 2021 Mark Verlinde <mark.verlinde@gmail.com>
- Rebuild for el7
* Wed Nov  4 2020 Axel Braun <axel.braun@gmx.de>
- version 1.13
  * Add arguments for CGI interpreters
  * Support multiple CGi interpreters
  * Buffering HTTP response headers, including API functions mg_response_header_* in C and Lua
  * Additional C API functions
  * Fix some memory leaks
  * Extended use of atomic operations (e.g., for server stats)
  * Add fuzz tests
  * Set OpenSSL 1.1 API as default (from 1.0)
  * Add Lua 5.4 support and deprecate Lua 5.1
  * Provide additional Lua API functions
  * Fix Lua websocket memory leak when closing the server
  * Remove obsolete "file in memory" implementation
  * Improvements and fixes in documentation
  * Fixes from static source code analysis
  * Additional unit tests
  * Various small bug fixes
  * Experimental support for some HTTP2 features (not ready for production)
  * Experimental support for websocket compression
  * Remove legacy interfaces declared obsolete since more than 3 years
* Fri Jul 10 2020 Axel Braun <axel.braun@gmx.de>
- version 1.12
  * fix-libpath.patch removed
  * See https://github.com/civetweb/civetweb/releases/tag/v1.12 for detailed changelog
* Thu Oct 31 2019 Ismail Dönmez <idonmez@suse.com>
- Add fix-libpath.patch to fix library install directory
* Sat Dec 22 2018 Axel Braun <axel.braun@gmx.de>
- Initial build at version 1.11.
  Thanks to malcolmlewis for helping with the specfile
